# Syre

Scientific data management and analysis.

```bash
python -m pip install syre
```
> Full documentation at [syre.ai](https://www.syre.ai).

Syre is a framework for managing and analyzing data. Syre utilizes **top-down organization** and **bottom-up analysis** to make analyzing your data and drawing conclusions easy. This allows your data and analysis to stay separate and modular.
